% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cache.R
\name{ato_cache_info}
\alias{ato_cache_info}
\title{Inspect the local ato cache}
\usage{
ato_cache_info()
}
\value{
A list with \code{dir}, \code{n_files}, \code{size_bytes},
\code{size_human}, and \code{files}.
}
\description{
Inspect the local ato cache
}
\examples{
\donttest{
op <- options(ato.cache_dir = tempdir())
ato_cache_info()
options(op)
}
}
\seealso{
Other configuration: 
\code{\link{ato_clear_cache}()},
\code{\link{ato_meta}()}
}
\concept{configuration}
