% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/manifest.R
\name{ato_manifest_clear}
\alias{ato_manifest_clear}
\title{Clear the session manifest}
\usage{
ato_manifest_clear()
}
\value{
Invisibly \code{NULL}. Useful at the top of a script when
running repeatedly.
}
\description{
Clear the session manifest
}
\examples{
ato_manifest_clear()
}
\seealso{
Other reproducibility: 
\code{\link{ato_deposit_zenodo}()},
\code{\link{ato_manifest}()},
\code{\link{ato_manifest_write}()},
\code{\link{ato_sha256}()},
\code{\link{ato_snapshot}()}
}
\concept{reproducibility}
